Module: Majoron::AntHill::SMPP::DisplayTime

Defined in:
lib/smpp_constants.rb

Overview

The display time parameter is used to associate a display time of the short message on the MS.

Constant Summary collapse

TEMPORARY =
0x00
DEFAULT =
0x01
INVOKE =
0x02