Module: Majoron::AntHill::SMPP::MessageState
- Defined in:
- lib/smpp_constants.rb
Overview
The following is a list of allowable states for a short message. The message_state value is returned by the SMSC to the ESME as part of the query_sm_resp PDU.
Constant Summary collapse
- ENROUTE =
The message is in enroute state.
0x01- DELIVERED =
Message is delivered todestination.
0x02- EXPIRED =
Message validity period hasexpired.
0x03- DELETED =
Message has been deleted.
0x04- UNDELIVERABLE =
Message is undeliverable.
0x05- ACCEPTED =
Message is in accepted state (i.e. has been manually read on behalf of the subscriber by customer service).
0x06- UNKNOWN =
Message is in invalid state.
0x07- REJECTED =
Message is in a rejected state.
0x08- SKIPPED =
The message was accepted but not transmitted or broadcast on the network.
0x09