Module: Majoron::AntHill::SMPP::UssdServiceOp
- Defined in:
- lib/smpp_constants.rb
Overview
The ussd service op parameter is required to define the USSD service operation when SMPP is being used as an interface to a (GSM) USSD system.
Constant Summary collapse
- PSSD_INDICATION =
0x00- PSSR_INDICATION =
0x01- USSR_REQUEST =
0x02- USSN_REQUEST =
0x03- PSSD_RESPONSE =
0x10- PSSR_RESPONSE =
0x11- USSR_CONFIRM =
0x12- USSN_CONFIRM =
0x13